==> libppi-perl_0.903.orig.tar.gz: PPI-0.903/lib/PPI/Document/Fragment.pm <==
package PPI::Document::Fragment;

=pod

=head1 NAME

PPI::Document::Fragment - A fragment of a Perl Document

=head1 DESCRIPTION

In some situations you might want to work with a fragment of a larger
document. PPI::Document::Fragment is a class intended for this purpose. It
is functionaly almost identical to a normal L<PPI::Document|PPI::Document>,
except that it is not possible to get line/column positions for the elements
within it, and it does not represent a scope.

=head1 METHODS

=cut

use strict;
use base 'PPI::Document';
use UNIVERSAL 'isa';

use vars qw{$VERSION};
BEGIN {
	$VERSION = '0.903';
}





#####################################################################
# PPI::Document Methods

=pod

=head2 index_locations

Unlike when called on a PPI::Document object, you should not be attempting
to find locations of things within a PPI::Document::Fragment, and thus any
call to the C<index_locations> will print a warning and return C<undef>
instead of attempting to index the locations of the Elements.

=cut

# There's no point indexing a fragment
sub index_locations {
	warn "Useless attempt to index the locations of a document fragment";
	undef;
}





#####################################################################
# PPI::Element Methods

# We are not a scope boundary
### XS -> PPI/XS.xs:_PPI_Document_Fragment__scope 0.903+
sub scope { '' }

1;

=pod

=head1 TO DO

Integrate this into the rest of PPI so it has actual practical uses. The most
obvious would be to implement arbitrary cut/copy/paste more easily.

=head1 SUPPORT

See the L<support section|PPI/SUPPORT> in the main module

=head1 AUTHOR

Adam Kennedy (Maintainer), L<http://ali.as/>, cpan@ali.as

=head1 COPYRIGHT

Copyright (c) 2004 - 2005 Adam Kennedy. All rights reserved.

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=cut

==> libppi-perl_1.115.orig.tar.gz: PPI-1.115/lib/PPI/Document/Fragment.pm <==
package PPI::Document::Fragment;

=pod

=head1 NAME

PPI::Document::Fragment - A fragment of a Perl Document

=head1 DESCRIPTION

In some situations you might want to work with a fragment of a larger
document. C<PPI::Document::Fragment> is a class intended for this purpose.
It is functionaly almost identical to a normal L<PPI::Document>, except
that it is not possible to get line/column positions for the elements
within it, and it does not represent a scope.

=head1 METHODS

=cut

use strict;
use base 'PPI::Document';

use vars qw{$VERSION};
BEGIN {
	$VERSION = '1.115';
}





#####################################################################
# PPI::Document Methods

=pod

=head2 index_locations

Unlike when called on a PPI::Document object, you should not be attempting
to find locations of things within a PPI::Document::Fragment, and thus any
call to the C<index_locations> will print a warning and return C<undef>
instead of attempting to index the locations of the Elements.

=cut

# There's no point indexing a fragment
sub index_locations {
	warn "Useless attempt to index the locations of a document fragment";
	undef;
}





#####################################################################
# PPI::Element Methods

# We are not a scope boundary
### XS -> PPI/XS.xs:_PPI_Document_Fragment__scope 0.903+
sub scope { '' }

1;

=pod

=head1 TO DO

Integrate this into the rest of PPI so it has actual practical uses. The most
obvious would be to implement arbitrary cut/copy/paste more easily.

=head1 SUPPORT

See the L<support section|PPI/SUPPORT> in the main module

=head1 AUTHOR

Adam Kennedy, L<http://ali.as/>, cpan@ali.as

=head1 COPYRIGHT

Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=cut
